@@ -149,7 +149,7 @@ about_verb_cb (BonoboUIComponent *uic,
 
 	quick_lounge->about_dialog = gnome_about_new (_("Quick Lounge"), 
 						      VERSION,
-						      _("Copyright (C) 2002 Free Software Foundation, Inc."),
+						      _("Copyright \xc2\xa9 2002 Free Software Foundation, Inc."),
 						      _("Organize your favourite applications on the Panel"),
 						      authors,
 						      documenters,
@@ -1596,7 +1596,7 @@ quick_lounge_applet_fill (PanelApplet *applet)
 	panel_applet_add_preferences (applet, "/schemas/apps/quick_lounge_applet/prefs", NULL);
 
 	min_cols = panel_applet_gconf_get_int (applet, PREFS_MIN_VISIBLE_COLS, &error);
-	if ((error != NULL) || (min_cols <= 0)) {
+	if ((error != NULL) || (min_cols < 0)) {
 		g_clear_error (&error);
 		min_cols = DEFAULT_MIN_VISIBLE_COLS;
 	}
